/**
 * Repräsentation einer Klausur mit einem Titel und einer Liste von angemeldeten
 * Studenten.
 * 
 * @author Annabelle Klarl
 * 
 */
public class KlausurH {
	private String titel;
	private Student[] teilnehmer;
	private int anzahlAngemeldete;

	/**
	 * Konstruktur
	 * 
	 * @param titel
	 *            Titel der Klausur
	 * @param maxTeilnehmer
	 *            maximale Anzahl an Teilnehmern
	 */
	public KlausurH(String titel, int maxTeilnehmer) {
		this.titel = titel;
		this.teilnehmer = new Student[maxTeilnehmer];
		this.anzahlAngemeldete = 0;
	}

	/**
	 * Diese Methode liefert den Titel der Klausur
	 * 
	 * @return
	 */
	public String getTitel() {
		return this.titel;
	}

	/**
	 * Diese Methode meldet einen Studenten mit der gegebenen Matrikelnummer und
	 * dem gegebenen Namen an. Dazu wird zunächst ein neues Objekt der Klasse
	 * {@link Student} erzeugt, dieser an der Klausur angemeldet und true
	 * zurückgegeben. Ist die Klausur schon voll (d.h. wird die Maximalanzahl an
	 * Teilnehmern überschritten), wird der Student nicht angemeldet und false
	 * zurückgegeben.
	 * 
	 * @param matrNr
	 * @param name
	 * @return false falls die Maximalanzahl an Teilnehmern überschritten wurde,
	 *         true sonst
	 */
	public boolean anmelden(int matrNr, String name) {
		if (this.anzahlAngemeldete < this.teilnehmer.length) {
			this.teilnehmer[this.anzahlAngemeldete] = new Student(matrNr, name);
			this.anzahlAngemeldete++;
			return true;
		}
		return false;
	}

	/**
	 * Diese Methode sucht in der Liste an Teilnehmern der Klausur einen
	 * Studenten mit der gegebenen Matrikelnummer. Wird ein Student gefunden,
	 * wird dieser zurückgegeben. Falls kein Student mit dieser Matrikelnummer
	 * angemeldet ist, wird null zurückgegeben.
	 * 
	 * @param matrNr
	 * @return das Objekt der Klasse Student mit der gegebenen Matrikelnummer;
	 *         null falls kein Student mit dieser Matrikelnummer gefunden wird.
	 */
	public Student sucheStudent(int matrNr) {
		for (int i = 0; i < this.anzahlAngemeldete; i++) {
			Student aktuellerStudent = this.teilnehmer[i];
			if (aktuellerStudent.getMatrNr() == matrNr) {
				return aktuellerStudent;
			}
		}
		return null;
	}

	/**
	 * Diese Methode trägt für einen Studenten mit der gegebenen Matrikelnummer
	 * die gegebene Note ein. Falls ein Student mit dieser Matrikelnummer an der
	 * Klausur angemeldet ist, wird die Note eingetragen und true zurückgegeben.
	 * Falls kein Student angemeldet ist, wird false zurückgegeben.
	 * 
	 * @param matrNr
	 * @param note
	 * @return true falls ein Student mit der gegebenen Matrikelnummer an der
	 *         Klausur angemeldet ist (und die Note eingetragen wurde); false
	 *         sonst
	 */
	public boolean noteEintragen(int matrNr, double note) {
		Student student = this.sucheStudent(matrNr);
		if (student != null) {
			student.setNote(note);
			return true;
		}
		return false;
	}

	/**
	 * Diese Methode berechnet die Durchschnittsnote aller benoteten
	 * Teilnehmern. Falls es keine benoteten Teilnehmer gab, wird -1
	 * zurückgegeben.
	 * 
	 * @return Die Durchschnittsnote aller benoteten Teilnehmer; falls es keine
	 *         benoteten Teilnehmer gibt, -1
	 */
	public double durchschnittsnote() {
		double notenAddiert = 0.0;
		double anzahlMitschreiber = 0;

		for (int i = 0; i < this.anzahlAngemeldete; i++) {
			Student aktuellerStudent = this.teilnehmer[i];
			double note = aktuellerStudent.getNote();
			if (note > -1) {
				notenAddiert = notenAddiert + note;
				anzahlMitschreiber++;
			}
		}

		if (anzahlMitschreiber == 0) {
			return -1;
		}
		else {
			return notenAddiert / anzahlMitschreiber;
		}
	}

	/**
	 * Diese Methode gibt zurück, wie viele Studenten die gegebene Note in der
	 * Klausur erreicht haben.
	 * 
	 * @param note
	 * @return Die Anzahl an Studenten, die diese Note erreicht haben.
	 */
	public int anzahlAnStudentenMitNote(double note) {
		int anzahl = 0;
		for (int i = 0; i < this.anzahlAngemeldete; i++) {
			Student aktuellerStudent = this.teilnehmer[i];
			if (Double.compare(aktuellerStudent.getNote(), note) == 0) {
				anzahl++;
			}
		}
		return anzahl;
	}
}
